aboutsummaryrefslogtreecommitdiff
path: root/gdb/python/py-progspace.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/python/py-progspace.c')
-rw-r--r--gdb/python/py-progspace.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/gdb/python/py-progspace.c b/gdb/python/py-progspace.c
index aa1e713..bb44aa4 100644
--- a/gdb/python/py-progspace.c
+++ b/gdb/python/py-progspace.c
@@ -55,8 +55,8 @@ struct pspace_object
/* The debug method list. */
PyObject *xmethods;
- /* The missing debug handler list. */
- PyObject *missing_debug_handlers;
+ /* The missing file handler list. */
+ PyObject *missing_file_handlers;
};
extern PyTypeObject pspace_object_type
@@ -166,7 +166,7 @@ pspy_dealloc (PyObject *self)
Py_XDECREF (ps_self->frame_unwinders);
Py_XDECREF (ps_self->type_printers);
Py_XDECREF (ps_self->xmethods);
- Py_XDECREF (ps_self->missing_debug_handlers);
+ Py_XDECREF (ps_self->missing_file_handlers);
Py_TYPE (self)->tp_free (self);
}
@@ -202,8 +202,8 @@ pspy_initialize (pspace_object *self)
if (self->xmethods == NULL)
return 0;
- self->missing_debug_handlers = PyList_New (0);
- if (self->missing_debug_handlers == nullptr)
+ self->missing_file_handlers = PyList_New (0);
+ if (self->missing_file_handlers == nullptr)
return 0;
return 1;
@@ -349,18 +349,18 @@ pspy_get_xmethods (PyObject *o, void *ignore)
/* Return the list of missing debug handlers for this program space. */
static PyObject *
-pspy_get_missing_debug_handlers (PyObject *o, void *ignore)
+pspy_get_missing_file_handlers (PyObject *o, void *ignore)
{
pspace_object *self = (pspace_object *) o;
- Py_INCREF (self->missing_debug_handlers);
- return self->missing_debug_handlers;
+ Py_INCREF (self->missing_file_handlers);
+ return self->missing_file_handlers;
}
/* Set this program space's list of missing debug handlers to HANDLERS. */
static int
-pspy_set_missing_debug_handlers (PyObject *o, PyObject *handlers,
+pspy_set_missing_file_handlers (PyObject *o, PyObject *handlers,
void *ignore)
{
pspace_object *self = (pspace_object *) o;
@@ -380,9 +380,9 @@ pspy_set_missing_debug_handlers (PyObject *o, PyObject *handlers,
}
/* Take care in case the LHS and RHS are related somehow. */
- gdbpy_ref<> tmp (self->missing_debug_handlers);
+ gdbpy_ref<> tmp (self->missing_file_handlers);
Py_INCREF (handlers);
- self->missing_debug_handlers = handlers;
+ self->missing_file_handlers = handlers;
return 0;
}
@@ -778,8 +778,8 @@ static gdb_PyGetSetDef pspace_getset[] =
"Type printers.", NULL },
{ "xmethods", pspy_get_xmethods, NULL,
"Debug methods.", NULL },
- { "missing_debug_handlers", pspy_get_missing_debug_handlers,
- pspy_set_missing_debug_handlers, "Missing debug handlers.", NULL },
+ { "missing_file_handlers", pspy_get_missing_file_handlers,
+ pspy_set_missing_file_handlers, "Missing file handlers.", NULL },
{ NULL }
};